kedro.extras.datasets.pandas.SQLQueryDataSet — Kedro 0.17.6 documentation

# kedro.extras.datasets.pandas.SQLQueryDataSet

class `kedro.extras.datasets.pandas.` `SQLQueryDataSet`(sql=None, credentials=None, load_args=None, fs_args=None, filepath=None)

  `SQLQueryDataSet` loads data from a provided SQL query. It uses `pandas.DataFrame` internally, so it supports all allowed pandas options on `read_sql_query`. Since Pandas uses SQLAlchemy behind the scenes, when instantiating `SQLQueryDataSet` one needs to pass a compatible connection string either in `credentials` (see the example code snippet below) or in `load_args`. Connection string formats supported by SQLAlchemy can be found here: https://docs.sqlalchemy.org/en/13/core/engines.html#database-urls

  It does not support save method so it is a read only data set. To save data to a SQL server use `SQLTableDataSet`.

  Example adding a catalog entry with YAML API:

      shuttle_id_dataset:
        type: pandas.SQLQueryDataSet
        sql: "select shuttle, shuttle_id from spaceflights.shuttles;"
        credentials: db_credentials
        layer: raw

  Sample database credentials entry in `credentials.yml`:

      db_creds:
          con: postgresql://scott:tiger@localhost/test

  Example using Python API:

      from kedro.extras.datasets.pandas import SQLQueryDataSet
      import pandas as pd

      data = pd.DataFrame({"col1": [1, 2], "col2": [4, 5],
                           "col3": [5, 6]})
      sql = "SELECT * FROM table_a"
      credentials = {
          "con": "postgresql://scott:tiger@localhost/test"
      }
      data_set = SQLQueryDataSet(sql=sql,
                                 credentials=credentials)

      sql_data = data_set.load()

  Methods

  `exists`() | Checks whether a data set’s output already exists by calling the provided _exists() method.
  `from_config`(name, config[, load_version, …]) | Create a data set instance using the configuration provided.
  `load`() | Loads data by delegation to the provided load method.
  `release`() | Release any cached data.
  `save`(data) | Saves data by delegation to the provided save method.

  `__init__`(sql=None, credentials=None, load_args=None, fs_args=None, filepath=None)

    Creates a new `SQLQueryDataSet`.

    Parameters

      - sql (`Optional`[`str`]) – The sql query statement.

      - credentials (`Optional`[`Dict`[`str`, `Any`]]) – A dictionary with a `SQLAlchemy` connection string. Users are supposed to provide the connection string ‘con’ through credentials. It overwrites con parameter in `load_args` and `save_args` in case it is provided. To find all supported connection string formats, see here: https://docs.sqlalchemy.org/en/13/core/engines.html#database-urls

      - load_args (`Optional`[`Dict`[`str`, `Any`]]) – Provided to underlying pandas `read_sql_query` function along with the connection string. To find all supported arguments, see here: https://pandas.pydata.org/pandas-docs/stable/generated/pandas.read_sql_query.html To find all supported connection string formats, see here: https://docs.sqlalchemy.org/en/13/core/engines.html#database-urls

      - fs_args (`Optional`[`Dict`[`str`, `Any`]]) – Extra arguments to pass into underlying filesystem class constructor (e.g. {“project”: “my-project”} for `GCSFileSystem`), as well as to pass to the filesystem’s open method through nested keys open_args_load and open_args_save. Here you can find all available arguments for open: https://filesystem-spec.readthedocs.io/en/latest/api.html#fsspec.spec.AbstractFileSystem.open All defaults are preserved, except mode, which is set to r when loading.

      - filepath (`Optional`[`str`]) – A path to a file with a sql query statement.

    Raises

      DataSetError – When either `sql` or `con` parameters is empty.

  `exists`()

    Checks whether a data set’s output already exists by calling the provided _exists() method.

    Return type

      `bool`

    Returns

      Flag indicating whether the output already exists.

    Raises

      DataSetError – when underlying exists method raises error.

  classmethod `from_config`(name, config, load_version=None, save_version=None)

    Create a data set instance using the configuration provided.

    Parameters

      - name (`str`) – Data set name.

      - config (`Dict`[`str`, `Any`]) – Data set config dictionary.

      - load_version (`Optional`[`str`]) – Version string to be used for `load` operation if the data set is versioned. Has no effect on the data set if versioning was not enabled.

      - save_version (`Optional`[`str`]) – Version string to be used for `save` operation if the data set is versioned. Has no effect on the data set if versioning was not enabled.

    Return type

      `AbstractDataSet`

    Returns

      An instance of an `AbstractDataSet` subclass.

    Raises

      DataSetError – When the function fails to create the data set from its config.

  `load`()

    Loads data by delegation to the provided load method.

    Return type

      `Any`

    Returns

      Data returned by the provided load method.

    Raises

      DataSetError – When underlying load method raises error.

  `release`()

    Release any cached data.

    Raises

      DataSetError – when underlying release method raises error.

    Return type

      `None`

  `save`(data)

    Saves data by delegation to the provided save method.

    Parameters

      data (`Any`) – the value to be saved by provided save method.

    Raises

      - DataSetError – when underlying save method raises error.

      - FileNotFoundError – when save method got file instead of dir, on Windows.

      - NotADirectoryError – when save method got file instead of dir, on Unix.

    Return type

      `None`